@@ -1,14 +1,13 @@
 from __future__ import absolute_import
 
 import pytest
-pytest.importorskip('numpy')
+np = pytest.importorskip('numpy')  # noqa
 
-import numpy as np
-import os
-import shutil
 import pickle
 
-from partd.numpy import Numpy, decode
+import partd
+from partd.numpy import Numpy
+
 
 def test_numpy():
     dt = np.dtype([('a', 'i4'), ('b', 'i2'), ('c', 'f8')])
@@ -43,8 +42,13 @@ def test_serialization():
         assert (q.get('x') == [1, 2, 3]).all()
 
 
-def test_object_dtype():
-    x = np.array(['Alice', 'Bob', 'Charlie'], dtype='O')
+array_of_lists = np.empty(3, dtype='O')
+array_of_lists[:] = [[1, 2], [3, 4], [5, 6]]
+
+
+@pytest.mark.parametrize('x', [np.array(['Alice', 'Bob', 'Charlie'], dtype='O'),
+                               array_of_lists])
+def test_object_dtype(x):
     with Numpy() as p:
         p.append({'x': x})
         p.append({'x': x})
@@ -61,7 +65,8 @@ def test_datetime_types():
         assert p.get('y').dtype == y.dtype
 
 
-def test_decode():
-    assert decode([]) == []
-    assert decode(np.nan) is np.nan
-    assert decode([b'a', 1]) == ['a', 1]
+def test_non_utf8_bytes():
+    a = np.array([b'\xc3\x28', b'\xa0\xa1', b'\xe2\x28\xa1', b'\xe2\x82\x28',
+                  b'\xf0\x28\x8c\xbc'], dtype='O')
+    s = partd.numpy.serialize(a)
+    assert (partd.numpy.deserialize(s, 'O') == a).all()
